==> mozc-1.0.558.102.tar.bz2: mozc-1.0.558.102/mac/common.h <==
// Copyright 2010, Google Inc.
// All rights reserved.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are
// met:
//
//     * Redistributions of source code must retain the above copyright
// notice, this list of conditions and the following disclaimer.
//     * Redistributions in binary form must reproduce the above
// copyright notice, this list of conditions and the following disclaimer
// in the documentation and/or other materials provided with the
// distribution.
//     * Neither the name of Google Inc. nor the names of its
// contributors may be used to endorse or promote products derived from
// this software without specific prior written permission.
//
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
// "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
// LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
// A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
// OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
// SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
// LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
// DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
// THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
// (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
// OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

namespace mozc {
namespace commands {
class Output;
}  // namespace mozc::commands
}  // namespace mozc

// ControllerCallback is the collection of methods which will be
// called from GoogleJapaneseInputServer.  Each Controller should
// implement these methods (although there is only one method right
// now).
@protocol ControllerCallback
- (void)candidateClicked:(int)id;

// In the future, some utility tools will send the result text via
// this method.
- (void)outputResult:(mozc::commands::Output *)data;
@end

// RendererCallback is a protocol to send the clicked information back
// to the UI client.  We don't use normal ipc mechanism for this
// because our UI client process is not a server.  Rather we free-ride
// the existing connection of normal IMKit.
@protocol ServerCallback
// This method is called when a user clicks an item in a candidate
// window.  The |data| contains a serialized protobuf message.
- (void)rendererClicked:(NSData *)data;

// Register the current controller.
- (void)setCurrentController:(id<ControllerCallback>)controller;

// outputResult is a method which calls outputResult: of the current
// controller.
- (void)outputResult:(NSData *)data;
@end

==> mozc_1.11.1522.102.orig.tar.bz2: mozc-1.11.1522.102/mac/common.h <==
// Copyright 2010-2013, Google Inc.
// All rights reserved.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are
// met:
//
//     * Redistributions of source code must retain the above copyright
// notice, this list of conditions and the following disclaimer.
//     * Redistributions in binary form must reproduce the above
// copyright notice, this list of conditions and the following disclaimer
// in the documentation and/or other materials provided with the
// distribution.
//     * Neither the name of Google Inc. nor the names of its
// contributors may be used to endorse or promote products derived from
// this software without specific prior written permission.
//
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
// "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
// LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
// A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
// OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
// SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
// LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
// DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
// THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
// (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
// OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

namespace mozc {
namespace commands {
class Output;
class SessionCommand;
}  // namespace mozc::commands
}  // namespace mozc

// ControllerCallback is the collection of methods which will be
// called from GoogleJapaneseInputServer.  Each Controller should
// implement these methods (although there is only one method right
// now).
@protocol ControllerCallback
- (void)sendCommand:(mozc::commands::SessionCommand &)data;

// In the future, some utility tools will send the result text via
// this method.
- (void)outputResult:(mozc::commands::Output *)data;
@end

// RendererCallback is a protocol to send the clicked information and
// usage stats event information back to the UI client.
// We don't use normal ipc mechanism for this because our UI client
// process is not a server.  Rather we free-ride the existing connection
// of normal IMKit.
@protocol ServerCallback
// This method is called when a user clicks an item in a candidate
// window or when the renderer sends the usage stats event information.
// The |data| contains a serialized protobuf message.
- (void)sendData:(NSData *)data;

// Register the current controller.
- (void)setCurrentController:(id<ControllerCallback>)controller;

// outputResult is a method which calls outputResult: of the current
// controller.
- (void)outputResult:(NSData *)data;
@end
